const fs = require('fs')
const path = require('path')
const baseConfig = require('./webpack.base')
const { merge } = require('webpack-merge')
// 清除构建目录
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const VueLoaderPlugin = require('vue-loader/lib/plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const TerserPlugin = require('terser-webpack-plugin')
const components = require('../components.json');

const resolve = name => {
    return path.resolve(__dirname, name)
}

let modules = {}

Object.keys(components).forEach(name => {
    modules[name] = path.join(__dirname, '../', components[name])
})
console.log(modules)

const config = {
    mode: 'production',
    // mode: 'development',
    devtool: 'source-map',
    entry: modules,
    output: {
        path: path.resolve(__dirname, '../lib'),
        filename: '[name].js',
        libraryTarget: 'umd',
        library: 'vue-element-ui-plus',
        libraryExport: 'default'
    },
    externals: {
        vue: 'vue'
    },
    optimization: {
        minimize: true,
        minimizer: [
            new TerserPlugin({
                extractComments: false,
                terserOptions: {
                    format: {
                        comments: false,
                    },
                },
            }),
        ],
    },
    plugins: [
        new VueLoaderPlugin(),
        new CleanWebpackPlugin(),
        new MiniCssExtractPlugin({
            filename: '../lib/css/[name].css'
        })
    ]
}

module.exports = merge(config, baseConfig)
